==> tdm_2.1.1.tar.gz: tdm/R/all.Amidihirss.R <==
all.Amidihirss<-function(){
     cat("\n")                                                                       
     cat("--------------------------------------------------------------\n")
     cat("    --Aminophylline dihydrous IR input data information--     \n")
     note_for_Theirss_input()
     cat("--------------------------------------------------------------\n")
     cat("\n")
     note_for_close_window()
     AmidihirSSpar<-data.frame(parameter=c("Gender","age (yr)","ht (cm)","CHF","smoke","D (mg)","tau (hr)","ts (hr)","c (mg/L)"),value=c(0))                                            
     AmidihirSSpar<-edit(AmidihirSSpar)                                                                                                                                           
     AmidihirSSpar<-ycheck(AmidihirSSpar)    
     cat("\n")                                                                                                                                                                                                                                                                        
     Amidihir.ss(AmidihirSSpar[9,2],AmidihirSSpar[7,2],AmidihirSSpar[8,2],AmidihirSSpar[6,2],AmidihirSSpar[3,2],AmidihirSSpar[2,2],AmidihirSSpar[5,2],AmidihirSSpar[1,2],AmidihirSSpar[4,2])
     note_for_convergence_plots()
     convergence_plots_sep()
     cat("------------------------------------------------------------------\n")
     cat("    --Aminophylline dihydrous IR output data information--        \n")
     note_for_Theirss_output()
     cat("------------------------------------------------------------------\n")   
     show(samplesStats("*"))
     cat("\n") 
     C<-TheIRsscpr(0.8,AmidihirSSpar[6,2],AmidihirSSpar[7,2],AmidihirSSpar[8,2])
     sim<-matrix(C[1 ,1])
     coutput<-data.frame(sim)
     colnames(coutput)<-list("Cmss_pr (mg/L)")
     output1<-coutput
     show(coutput)
     r=log(1.85-(samplesStats("cl_F")/samplesStats("v_F")))/(1.85-(samplesStats("cl_F")/samplesStats("v_F")))
     C<-TheIRsscpr(0.8,AmidihirSSpar[6,2],AmidihirSSpar[7,2],r)
     sim<-matrix(C[1 ,1])
     coutput<-data.frame(sim)
     colnames(coutput)<-list("Cpss_pr (mg/L)")
     output2<-coutput
     show(coutput)
     C<-TheIRsscpr(0.8,AmidihirSSpar[6,2],AmidihirSSpar[7,2],AmidihirSSpar[7,2])
     sim<-matrix(C[1 ,1])
     coutput<-data.frame(sim)
     colnames(coutput)<-list("Ctss_pr (mg/L)")
     output3<-coutput
     show(coutput)     
     cat("\n")   
     Amidihir.more()                                     
}

==> tdm_2.2.1.tar.gz: tdm/R/all.Amidihirss.R <==
all.Amidihirss<-function(){
     cat("\n")                                                                       
     cat("--------------------------------------------------------------\n")
     cat("    --Aminophylline dihydrous IR input data information--     \n")
     note_for_Theirss_input()
     cat("--------------------------------------------------------------\n")
     cat("\n")
     note_for_close_window()
     AmidihirSSpar<-data.frame(parameter=c("Gender","age (yr)","ht (cm)","CHF","smoke","D (mg)","tau (hr)","ts (hr)","c (mg/L)"),value=c(0))                                            
     AmidihirSSpar<-edit(AmidihirSSpar)                                                                                                                                           
##     AmidihirSSpar<-ycheck(AmidihirSSpar)    
     cat("\n")                                                                                                                                                                                                                                                                        
     Amidihir.ss(AmidihirSSpar[9,2],AmidihirSSpar[7,2],AmidihirSSpar[8,2],AmidihirSSpar[6,2],AmidihirSSpar[3,2],AmidihirSSpar[2,2],AmidihirSSpar[5,2],AmidihirSSpar[1,2],AmidihirSSpar[4,2])
     note_for_convergence_plots()
     convergence_plots_sep()
     cat("------------------------------------------------------------------\n")
     cat("    --Aminophylline dihydrous IR output data information--        \n")
     note_for_Theirss_output()
     cat("------------------------------------------------------------------\n")   
     show(samplesStats("*"))
     cat("\n") 
     C<-TheIRsscpr(0.8,AmidihirSSpar[6,2],AmidihirSSpar[7,2],AmidihirSSpar[8,2])
     sim<-matrix(C[1 ,1])
     coutput<-data.frame(sim)
     colnames(coutput)<-list("Cmss_pr (mg/L)")
     output1<-coutput
     show(coutput)
     r=log(1.85-(samplesStats("cl_F")/samplesStats("v_F")))/(1.85-(samplesStats("cl_F")/samplesStats("v_F")))
     C<-TheIRsscpr(0.8,AmidihirSSpar[6,2],AmidihirSSpar[7,2],r)
     sim<-matrix(C[1 ,1])
     coutput<-data.frame(sim)
     colnames(coutput)<-list("Cpss_pr (mg/L)")
     output2<-coutput
     show(coutput)
     C<-TheIRsscpr(0.8,AmidihirSSpar[6,2],AmidihirSSpar[7,2],AmidihirSSpar[7,2])
     sim<-matrix(C[1 ,1])
     coutput<-data.frame(sim)
     colnames(coutput)<-list("Ctss_pr (mg/L)")
     output3<-coutput
     show(coutput)     
     cat("\n")   
     Amidihir.more()                                     
}
